import setuptools


setuptools.setup(
    name="natthaphon",
    version="0.0.2",
    author="Natthaphon Hogcharoen",
    author_email="palm22180@gmail.com",
    description="A small package for my usage",
    long_description="No need for any description",
    long_description_content_type="text/markdown",
    url="https://github.com/DableUTeeF/pytorch_api",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
